@@ -40,13 +40,14 @@
 
 /* Xfce includes */
 #include <libxfce4util/libxfce4util.h>
-#include <libxfcegui4/libxfcegui4.h>
+//#include <libxfcegui4/libxfcegui4.h>
+#include <libxfce4ui/libxfce4ui.h>
 #include <libxfce4panel/xfce-panel-plugin.h>
 
 /* Package includes */
 #include <configuration.h>
 #include <sensors-interface.h>
-#include <sensors-interface-common.h>
+#include <sensors-interface-plugin.h> // includes sensors-interface-common.h
 #include <middlelayer.h>
 #include <cpu.h>
 
@@ -627,7 +628,9 @@ sensors_set_text_panel_label (t_sensors *sensors, gint numCols, gint itemsToDisp
             
             if (chipfeature->show == TRUE) {
                 if(sensors->show_labels==TRUE) {
-                  myLabelText = g_strconcat (myLabelText, "<span size=\"", sensors->font_size, "\">",chipfeature->name, ":</span> ", NULL);
+                  tmpstring = g_strconcat (myLabelText, "<span size=\"", sensors->font_size, "\">",chipfeature->name, ":</span> ", NULL);
+                  g_free(myLabelText);
+                  myLabelText = tmpstring;
                 }
                 
                 if (sensors->show_units) {
@@ -650,18 +653,29 @@ sensors_set_text_panel_label (t_sensors *sensors, gint numCols, gint itemsToDisp
                 myLabelText = tmpstring;
 
                 if (sensors->orientation == GTK_ORIENTATION_VERTICAL) {
-                    if (itemsToDisplay > 1)
-                        myLabelText = g_strconcat (myLabelText, "\n", NULL);
+                    if (itemsToDisplay > 1) {
+                        tmpstring = g_strconcat (myLabelText, "\n", NULL);
+                        g_free(myLabelText);
+                        myLabelText = tmpstring;
+                    }
                 }
                 else if (currentColumn < numCols-1) {
-                    if (sensors->show_smallspacings)
-                        myLabelText = g_strconcat (myLabelText, "  ", NULL);
-                    else
-                        myLabelText = g_strconcat (myLabelText, " \t", NULL);
+                    if (sensors->show_smallspacings) {
+                        tmpstring = g_strconcat (myLabelText, "  ", NULL);
+                        g_free(myLabelText);
+                        myLabelText = tmpstring;
+                    }
+                    else {
+                        tmpstring = g_strconcat (myLabelText, " \t", NULL);
+                        g_free(myLabelText);
+                        myLabelText = tmpstring;
+                    }
                     currentColumn++;
                 }
                 else if (itemsToDisplay > 1) { /* do NOT add \n if last item */
-                    myLabelText = g_strconcat (myLabelText, " \n", NULL);
+                    tmpstring = g_strconcat (myLabelText, " \n", NULL);
+                    g_free(myLabelText);
+                    myLabelText = tmpstring;
                     currentColumn = 0;
                 }
                 itemsToDisplay--;
@@ -790,6 +804,7 @@ sensors_create_tooltip (gpointer data)
                 if (prependedChipName != TRUE) {
 
                     if (first == TRUE) {
+                        g_free (myToolTipText);
                         myToolTipText = g_strdup (chip->sensorId);
                         first = FALSE;
                     }
@@ -844,6 +859,7 @@ sensors_create_tooltip (gpointer data)
     /* #if GTK_VERSION < 2.11 */
     gtk_tooltips_set_tip (tooltips, GTK_WIDGET(sensors->eventbox),
                           myToolTipText, NULL);
+		DBG("tooltip text: %s.\n", myToolTipText);
     TRACE ("freeing myToolTipText");
     g_free (myToolTipText);
 
@@ -1007,7 +1023,8 @@ execute_command (GtkWidget *widget, GdkEventButton *event, gpointer data)
 
         g_return_val_if_fail ( sensors->exec_command, FALSE);
 
-        xfce_exec (sensors->command_name, FALSE, FALSE, NULL);
+				// screen NULL, command, terminal=no, startup=yes, error=NULL
+        xfce_spawn_command_line_on_screen (NULL, sensors->command_name, FALSE, TRUE, NULL);
 
         TRACE ("leaves execute_command with TRUE");
 
@@ -1067,6 +1084,11 @@ sensors_free (XfcePanelPlugin *plugin, t_sensors *sensors)
     g_ptr_array_free (sensors->chips, TRUE);
 
     g_free (sensors->plugin_config_file);
+    g_free (sensors->command_name);
+/*
+    g_free (sensors->font);
+*/
+    g_free (sensors->font_size);
     g_free (sensors);
 
     TRACE ("leaves sensors_free");
@@ -2335,3 +2357,4 @@ sensors_plugin_construct (XfcePanelPlugin *plugin)
 }
 
 XFCE_PANEL_PLUGIN_REGISTER_EXTERNAL (sensors_plugin_construct);
+
